@@ -21,6 +21,16 @@ class YAMLTransformationError(Exception):
     """Raised if yafowil widget tree could not be build by YAML definitions.
     """
 
+class TBSupplement(object):
+
+    def __init__(self, obj, msg):
+        self.manageable_object = obj
+        self.msg = msg
+
+    def getInfo(self, html=1):
+        if html:
+            return '<pre>%s</pre>' % self.msg
+        return self.msg
 
 class YAMLParser(object):
     
@@ -75,6 +85,7 @@ class YAMLParser(object):
             for child in children_defs:
                 name = child.keys()[0]
                 child_def = child[name]
+                child_def['name'] = name
                 node[name] = call_factory(child_def)
                 create_children(node[name], child_def.get('widgets', []))
         root = call_factory(data)
@@ -85,10 +96,12 @@ class YAMLParser(object):
         if not isinstance(value, basestring):
             return value
         if value.startswith('expr:'):
-            return lambda widget=None, data=None: \
-                eval(value[5:],
-                     {'context': self.context, 'widget': widget, 'data': data},
-                     {})
+            def fetch_value(widget=None, data=None):
+                __traceback_supplement__ = (TBSupplement, self, str(value))
+                return eval(value[5:],
+                            {'context': self.context, 'widget': widget,
+                             'data': data}, {})
+            return fetch_value
         if value.startswith('i18n:'):
             return self.message_factory(value[5:])
         if not '.' in value:
